@@ -6,7 +6,8 @@ from threading import Event as ThreadEvent
 from threading import Thread
 from typing import List
 
-from grpc_helper.api import Event, EventFilter, EventInterrupt, ResultCode
+from grpc_helper_api import Event, EventFilter, EventInterrupt, ResultCode
+
 from grpc_helper.client import RpcClient
 from grpc_helper.errors import RpcException
 from grpc_helper.static_config import RPC_RETRY_DELAY
@@ -45,7 +46,7 @@ class EventsListener(ABC):
         retry_delay = RPC_RETRY_DELAY
         while True:
             try:
-                for s in self.client.events.listen(EventFilter(client_id=self.client_id, names=self.names)):
+                for s in self.client.events.listen(EventFilter(client_id=self.client_id, names=self.names)):  # pragma: no branch
                     # Success, restore retry delay
                     retry_delay = RPC_RETRY_DELAY
 
@@ -62,8 +63,16 @@ class EventsListener(ABC):
                         self.logger.debug(f"<< Event listener #{self.client_id} on_event({s.event.name})")
 
                 # Listen loop normal exit: listening was interrupted
-                break
+                self.logger.debug(f"Event listener #{self.client_id}: end of listening loop")
+                break  # pragma: no cover
             except Exception as e:
+                # Maybe the client ID is unknown
+                if isinstance(e, RpcException) and e.rc == ResultCode.ERROR_ITEM_UNKNOWN and self.client_id is not None:
+                    self.logger.warning(f"Event listening ID #{self.client_id} is unknown, ask for a new one")
+                    self.client_id = None
+                    continue
+
+                # Other error handling
                 error_trace = (
                     "event service restarting"
                     if isinstance(e, RpcException) and e.rc == ResultCode.ERROR_STREAM_SHUTDOWN
@@ -87,5 +96,5 @@ class EventsListener(ABC):
         """
         self.logger.debug(f">> Interrupting event listener #{self.client_id}")
         self.client.events.interrupt(EventInterrupt(client_id=self.client_id))
-        self.listening_t.join()
-        self.logger.debug(f"<< Interrupting event listener #{self.client_id}")
+        self.listening_t.join(30)  # Join with timeout, to avoid to be frozen; this already happened...
+        self.logger.debug(f"<< Interrupting event listener #{self.client_id} (thread still running: {self.listening_t.is_alive()})")
